require 'titantic/titantic'
require 'test_helper'

class TitanticTest < MiniTest::Test
  include MiniTest::Assertions
  def setup
  end
  
  describe 'Archive services', :vcr do
  #describe 'Archive services' do
    it 'uploads the given archive' do
      titantic = Titantic.new
      out = capture_io { titantic.upload_archive("test", "test/test.txt", description: 'some description', account_id: '-') }
      assert_equal Hash[ "status" => "success"],  JSON.parse(out[0])
    end

    it 'fails to upload the given archive because vault does not exist' do
      titantic = Titantic.new
      out = capture_io { titantic.upload_archive("blah", "test/test.txt", description: 'some description', account_id: '-') }
      assert_equal Hash["status" =>  "error", "error" => "Vault blah does not exist"], JSON.parse(out[0])
    end

    it 'fails to upload the given archive because archive does not exist on disk' do
      titantic = Titantic.new
      out = capture_io { titantic.upload_archive("test", "no archive", description: 'some description', account_id: '-') }
      assert_equal Hash["status" => "error", "error" => "Archive no archive does not exist"], JSON.parse(out[0])
    end
  end

  describe 'Vault services', :vcr do
  #describe 'Vault services' do
    it 'creates a new vault' do
      titantic = Titantic.new
      out = capture_io { titantic.create_vault("test") }
      data = JSON.parse(out[0])
      data["arn"] = "arn:aws:glacier:someserver:vaults/test"
      assert_equal Hash["id" => "test", "created_at" => "2014-03-11 03:09:28 UTC", "last_inventory_at" => "2014-03-24 22:15:31 UTC", "number_of_archives" => 3, "size_in_bytes" => 98379, "arn" => "arn:aws:glacier:someserver:vaults/test"], data
    end
    
    it 'should delete a vault' do
      titantic = Titantic.new
      titantic.create_vault("deleteme")
      out = capture_io { titantic.delete_vault("deleteme") }
      data = JSON.parse(out[0])
      data["headers"]["X-Amzn-Requestid"] = 'some id'
      assert_equal Hash["body" => "", "headers" => { "X-Amzn-Requestid" => "some id", "Date" => "Sun, 30 Mar 2014 21:40:21 GMT"}, "status" => 204, "remote_ip" => "127.0.0.1"], data
    end

    it 'list all vaults' do
      titantic = Titantic.new
      out = capture_io { titantic.list_vaults }
      assert_equal ["Images","mp3s","test"], JSON.parse(out[0])
    end
  end
end
